package com.faraphel.tasks_valider.ui.screen.communication.wifiP2p.server

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material3.Button
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.Text
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.text.input.KeyboardType
import com.faraphel.tasks_valider.connectivity.bwf.BwfManager
import com.faraphel.tasks_valider.connectivity.room.RoomServer
import com.faraphel.tasks_valider.ui.screen.communication.DEFAULT_SERVER_PORT
import com.faraphel.tasks_valider.ui.screen.communication.RANGE_SERVER_PORT
import com.faraphel.tasks_valider.ui.screen.tasks.TaskGroupScreen


@Composable
fun CommunicationWifiP2pServerScreen(bwfManager: BwfManager) {
    val server = remember { mutableStateOf<RoomServer?>(null)}

    // if the server is not created, prompt the user for the server configuration
    if (server.value == null) CommunicationWifiP2pServerContent(bwfManager, server)
    // else, go to the base tasks screen
    else TaskGroupScreen()
}


@Composable
fun CommunicationWifiP2pServerContent(
    bwfManager: BwfManager,
    server: MutableState<RoomServer?>
) {
    val expandedStudentList = remember { mutableStateOf(false) }
    val serverPort = remember { mutableIntStateOf(DEFAULT_SERVER_PORT) }

    Column {
        // student list
        Button(onClick = { expandedStudentList.value = !expandedStudentList.value }) {
            Text(text = "Select Students List")
        }
        DropdownMenu(
            expanded = expandedStudentList.value,
            onDismissRequest = { expandedStudentList.value = false }
        ) {
            DropdownMenuItem(
                text = { Text("ISRI") },
                onClick = {}
            )
            DropdownMenuItem(
                text = { Text("MIAGE") },
                onClick = {}
            )
            // TODO(Faraphel): student lists should be loaded from the database or a file
        }

        // server port
        TextField(
            value = serverPort.intValue.toString(),
            keyboardOptions = KeyboardOptions(keyboardType = KeyboardType.Number),
            onValueChange = { text ->
                val port = text.toInt()
                if (port in RANGE_SERVER_PORT) {
                    serverPort.intValue = port
                }
            }
        )

        Button(onClick = {
            bwfManager.recreateGroup {
                server.value = RoomServer(serverPort.intValue)
                server.value!!.start()
            }
        }) {
            Text("Create")
        }
    }
}